@@ -513,6 +513,13 @@ ientry_finalize (GObject *object)
 	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
+static void
+entry_changed(GtkEntry *entry)
+{
+	if (g_path_is_absolute(gtk_entry_get_text(entry)))
+		gtk_widget_activate(GTK_WIDGET(entry));
+}
+
 static void
 browse_clicked(GnomeFileEntry *fentry, GnomeIconEntry *ientry)
 {
@@ -533,6 +540,7 @@ browse_clicked(GnomeFileEntry *fentry, GnomeIconEntry *ientry)
 
 	g_return_if_fail (gtk_file_chooser_get_preview_widget (fc) == NULL);
 
+#if 0
 	w = gtk_frame_new("");
 	gtk_frame_set_shadow_type (GTK_FRAME (w), GTK_SHADOW_NONE);
 
@@ -549,6 +557,7 @@ browse_clicked(GnomeFileEntry *fentry, GnomeIconEntry *ientry)
 		setup_preview (GTK_WIDGET(fc));
 
 	g_free (path);
+#endif
 }
 
 static void
@@ -762,7 +771,7 @@ ientry_browse(GnomeIconEntry *ientry)
 
 		priv->icon_sel = gnome_icon_selection_new ();
 		_add_atk_name_desc (priv->icon_sel,
-				    _("Icon selector"),
+				    _("Icon Selector"),
 				    _("Please pick the icon you want."));
 
 		gnome_icon_selection_add_directory (GNOME_ICON_SELECTION (priv->icon_sel),
@@ -1037,6 +1046,8 @@ gnome_icon_entry_instance_init (GnomeIconEntry *ientry)
 	g_free(p);
 
 	w = gnome_file_entry_gtk_entry(GNOME_FILE_ENTRY(ientry->_priv->fentry));
+	g_signal_connect_after (w, "changed",
+				G_CALLBACK (entry_changed), ientry);
 
 	closure = g_cclosure_new (G_CALLBACK (entry_activated), ientry, NULL);
 	g_object_watch_closure (G_OBJECT (ientry), closure);
@@ -1266,7 +1277,7 @@ gnome_icon_entry_set_history_id(GnomeIconEntry *ientry,
  *
  * Description:  Set the max_saved of the entry in the browse dialog
  *
- * Returns:
+ * Since: 2.4
  **/
 void
 gnome_icon_entry_set_max_saved(GnomeIconEntry *ientry,
