@@ -167,9 +167,6 @@ update_pango_layout (GnomeIconTextItem *iti)
 static void
 iti_stop_editing (GnomeIconTextItem *iti)
 {
-	GnomeIconTextItemPrivate *priv;
-
-	priv = iti->_priv;
 	iti->editing = FALSE;
 	send_focus_event (iti, FALSE);
 	update_pango_layout (iti);
@@ -261,11 +258,9 @@ iti_stop_selecting (GnomeIconTextItem *iti, guint32 event_time)
 {
 	GnomeIconTextItemPrivate *priv;
 	GnomeCanvasItem *item;
-	GtkEditable *e;
 
 	priv = iti->_priv;
 	item = GNOME_CANVAS_ITEM (iti);
-	e = GTK_EDITABLE (priv->entry);
 
 	gnome_canvas_item_ungrab (item, event_time);
 	priv->selecting = FALSE;
@@ -553,7 +548,6 @@ gnome_icon_text_item_draw (GnomeCanvasItem *item, GdkDrawable *drawable,
 {
 	GtkWidget *widget;
 	GtkStyle *style;
-	GdkGC *gc, *bgc;
 	int xofs, yofs;
 	int text_xofs, text_yofs;
 	int w, h;
@@ -567,9 +561,6 @@ gnome_icon_text_item_draw (GnomeCanvasItem *item, GdkDrawable *drawable,
 
 	style = GTK_WIDGET (GNOME_CANVAS_ITEM (iti)->canvas)->style;
 
-	gc = style->fg_gc [GTK_STATE_NORMAL];
-	bgc = style->bg_gc [GTK_STATE_NORMAL];
-
 	w = priv->layout_width + 2 * MARGIN_X;
 	h = priv->layout_height + 2 * MARGIN_Y;
 
@@ -879,15 +870,8 @@ static void
 gnome_icon_text_item_destroy (GtkObject *object)
 {
 	GnomeIconTextItem *iti = GNOME_ICON_TEXT_ITEM (object);
-	GnomeCanvasItem *item = GNOME_CANVAS_ITEM (object);
 	GnomeIconTextItemPrivate *priv = iti->_priv;
 
-	gnome_canvas_request_redraw (item->canvas,
-				     ROUND (item->x1),
-				     ROUND (item->y1),
-				     ROUND (item->x2),
-				     ROUND (item->y2));
-
 	if (iti->text && iti->is_text_allocated) {
 		g_free (iti->text);
 		iti->text = NULL;
@@ -1108,6 +1092,13 @@ gnome_icon_text_item_setxy (GnomeIconTextItem *iti, int x, int y)
 	gnome_canvas_item_request_update (GNOME_CANVAS_ITEM (iti));
 }
 
+/**
+ * gnome_icon_text_item_focus:
+ * @iti:  An icon text item.
+ * @focused: whether to set or unset the icon text item focus.
+ *
+ * Sets or unsets the focus on the icon text item depending on @focused.
+ **/
 void
 gnome_icon_text_item_focus (GnomeIconTextItem *iti, gboolean focused)
 {
@@ -1226,6 +1217,14 @@ gnome_icon_text_item_stop_editing (GnomeIconTextItem *iti,
 		iti_stop_editing (iti);
 }
 
+/**
+ * gnome_icon_text_item_get_editable:
+ * @iti: An icon text item.
+ *
+ * Retrieves the entry widget associated with the icon text.
+ * 
+ * Returns: a #GtkEditable if the entry widget is initialised, NULL otherwise.
+ **/
 GtkEditable *
 gnome_icon_text_item_get_editable  (GnomeIconTextItem *iti)
 {
